<?php

switch ($messaggio) {

case "Configura e personalizza HotelDruid":	$messaggio = "Configurar i personalitzar HotelDruid"; break;
case "Scegli la lingua":  			$messaggio = "Escollir l'idioma"; break;
case "cambia la lingua":  			$messaggio = "canviar l'idioma"; break;
case "Tabella con tutte le prenotazioni":  	$messaggio = "Taula de reserves"; break;
case "Cambia la valuta":  			$messaggio = "Canviar la divisa"; break;
case "Scegli le colonne da far comparire":  	$messaggio = "Escollir les columnes que es mostraran"; break;
case "n° di settimane":  			$messaggio = "n° de setmanes"; break;
case "n° di giorni":  				$messaggio = "n° de dies"; break;
case "caparra":  				$messaggio = "arres"; break;
case "pagato":  				$messaggio = "cobrat"; break;
case "resto da pagare":  			$messaggio = "saldo a cobrar"; break;
case "n° di persone":  				$messaggio = "n° de persones"; break;
case "commento":  				$messaggio = "comentari"; break;
case "costo aggiuntivo unico":  		$messaggio = "suplement puntual"; break;
case "abbreviazione":  				$messaggio = "abreviació"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "suplement setmanal"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "suplement diari"; break;
case "cambia le colonne":  			$messaggio = "canviar les columnes"; break;
case "Tabelle dei mesi":  			$messaggio = "Planning mensual"; break;
case "Numero di tabelle del 2° tipo":  		$messaggio = "Número de taules del 2° tipus"; break;
case "cambia":  				$messaggio = "canviar"; break;
case "Torna al menù principale":  		$messaggio = "Torna al menú principal"; break;
case "a":  					$messaggio = "a"; break;
case "La lingua è stata cambiata":  		$messaggio = "L'idioma ha estat canviat"; break;
case "La valuta è stata cambiata":  		$messaggio = "La divisa ha estat canviada"; break;
case "Le colonne sono state cambiate":  	$messaggio = "Les columnes han estat canviades"; break;
case "Il numero di tabelle è stato cambiato":  	$messaggio = "La quantitat de taules ha estat canviat"; break;
case "cambia i nomi dei documenti":  		$messaggio = "canviar els noms dels documents"; break;
case "I nomi dei documenti sono stati cambiati":	$messaggio = "Els noms dels documents han estat canviats"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Format de visualització d'imports"; break;
case "cambia formato":  			$messaggio = "canviar format"; break;
case "Il formato di visualizzazione dei soldi è stato cambiato":	$messaggio = "el format de visualització d'imports ha estat canviat"; break;
case "Le date sono sbagliate":  		$messaggio = "Les dates són errònies"; break;
case "Le date dei menù a tendina sono state cambiate":	$messaggio = "Les dates de les llistes han estat canviades"; break;
case "Scegli le date":  			$messaggio = "Escollir les dates"; break;
case "nei menù a tendina":  			$messaggio = "a les listes"; break;
case "dal":  					$messaggio = "des del"; break;
case "al":  					$messaggio = "fins el"; break;
case "Tronca i cognomi nelle tabelle dopo ":	$messaggio = "Escapça els cognoms a les taules després de "; break;
case "caratteri per colonna":  			$messaggio = "caràcters per columna"; break;
case "La lunghezza dei cognomi nelle tabelle dei mesi è stata cambiata":	$messaggio = "La quantitat de caràcters dels cognoms al planning per mesos ha estat canviada"; break;
case "Cambia il numero delle tariffe":  	$messaggio = "Canviar la quantitat de tarifes"; break;
case "per l'anno":  				$messaggio = "de l'any"; break;
case "Il numero delle tariffe è stato cambiato":	$messaggio = "La quantitat de tarifes ha estat canviada"; break;
case "Il numero di tariffe è sbagliato":  	$messaggio = "La quantitat de tarifes és errònia"; break;
case "Sistema di backup":  			$messaggio = "sistema de còpies de seguretat"; break;
case "Il numero delle righe è sbagliato":  	$messaggio = "La quantitat de línies és errònia"; break;
case "Cambia il numero delle righe":  		$messaggio = "Canviar la quantitat de línies"; break;
case "Il numero delle righe della tabella con tutte le prenotazioni è stato cambiato":	$messaggio = "La quantitat de línies de la taula de reserves ha estat canviada"; break;
case "Il numero delle righe della tabella con la storia delle entrate e delle uscite è stato cambiato":	$messaggio = "La quantitat de línies de la taula de l'historial de cobraments ha estat canviada"; break;
case "Tabella con la storia delle entate e uscite":	$messaggio = "Taula historial de cobraments"; break;
case "Il formato di visualizzazione delle date è stato cambiato":	$messaggio = "El format de visualització de les dates ha estat canviat"; break;
case "Formato di visualizzazione delle date":	$messaggio = "Format de visualització de dates"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Taula de clients"; break;
case "Il numero delle righe della tabella con tutti i clienti è stato cambiato":	$messaggio = "La quantitat de línies de la taula de clients ha estat canviada"; break;
case "Si deve sceliere qualche dato da inserire nella colonna gruppo":	$messaggio = "Cal escollir alguna dada per inserir a la columna grup"; break;
case "Si deve inserire il nome della colonna gruppo":	$messaggio = "Hay que inserir el nom de la columna grup"; break;
case "La colonna gruppo è stata aggiunta":  	$messaggio = "La columna grup ha estat afegida"; break;
case "Aggiungi una colonna gruppo":  		$messaggio = "Afegeix una columna grup"; break;
case "Aggiungi colonna gruppo":  		$messaggio = "Afegeix columna grup"; break;
case "chiamata":  				$messaggio = "anomenada"; break;
case "con":  					$messaggio = "amb"; break;
case "colonna gruppo":  			$messaggio = "columna grup"; break;
case "separatore":  				$messaggio = "separador"; break;
case "spazio":  				$messaggio = "espai"; break;
case "trattino":  				$messaggio = "guió"; break;
case "a capo":  				$messaggio = "nova línia"; break;
case "Pagine per il sito web":  		$messaggio = "Pàgines del lloc web"; break;
case " Do":  					$messaggio = " Dg"; break;
case " Lu":  					$messaggio = " Dl"; break;
case " Ma":  					$messaggio = " Dm"; break;
case " Me":  					$messaggio = " Dc"; break;
case " Gi":  					$messaggio = " Dj"; break;
case " Ve":  					$messaggio = " Dv"; break;
case " Sa":  					$messaggio = " Ds"; break;
case "Gen":  					$messaggio = "Gen"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Abr"; break;
case "Mag":  					$messaggio = "Mai"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Ago"; break;
case "Set":  					$messaggio = "Set"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Des"; break;
case "nome della tariffa":  			$messaggio = "nom de la tarifa"; break;
case "data di inserimento":  			$messaggio = "data d'inserció"; break;
case "tariffa completa":  			$messaggio = "preu total"; break;
case "Gestione utenti":  			$messaggio = "Gestió d'usuaris"; break;
case "Personalizzazioni dell'utente":  		$messaggio = "Personaliztacions de l'usuari"; break;
case "Cambia":  				$messaggio = "Canviar"; break;
case "quelle di":  				$messaggio = "les de"; break;
case "Importa i nomi dei documenti":  		$messaggio = "Importals noms dels documents"; break;
case "Importa":  				$messaggio = "Importa"; break;
case "dell'utente":  				$messaggio = "de l'usuari"; break;
case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "Els minuts de duració de sessions i transaccions han estat canviats"; break;
case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "Les hores d'antelació del començament de les reserves han estat canviades"; break;
case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":	$messaggio = "Minuts després dels quals considerar acabades les sessions i transaccions no actualitzades"; break;
case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Quantitat d'hores d'antelació amb les quals es considerarà que s'és dins del rang de dates d'una reserva"; break;
case "utente":  				$messaggio = "usuari"; break;
case "Interconnessioni":  			$messaggio = "Interconnexions"; break;
case "Assegnazione automatica disattivata":  	$messaggio = "Assignació automàtica desactivada"; break;
case "Assegnazione automatica attivata":  	$messaggio = "Assignació automàtica activada"; break;
case "Attiva":  				$messaggio = "Activar"; break;
case "Disattiva":  				$messaggio = "Desactivar"; break;
case "Scegli il tema grafico":  		$messaggio = "Escollir el tema gràfic"; break;
case "Il tema grafico è stato cambiato":  	$messaggio = "El tema gràfic ha estat canviat"; break;
case "Registrazione degli orari di entrata ed uscita attivata":	$messaggio = "Registre d'hores d'arribada i sortida activat"; break;
case "Registrazione degli orari di entrata ed uscita disattivata":	$messaggio = "Registre d'hores d'arribada i sortida desactivat"; break;
case "Le ore di differenza con l'orario del server sono state cambiate":	$messaggio = "La difèrencia horària entre l'hora del servidor i l'hora local ha estat canviada"; break;
case "Ore di differenza con l'orario del server":	$messaggio = "Difèrencia en hores entre l'hora del servidor i l'hora local"; break;
case "ora attuale":  				$messaggio = "hora actual"; break;
case "numero":  				$messaggio = "número"; break;
case "cognome cliente":  			$messaggio = "cognom client"; break;
case "data iniziale":  				$messaggio = "data d'arribada"; break;
case "data finale":  				$messaggio = "data de sortida"; break;
case "Le colonne necessarie sono state cambiate":	$messaggio = "Les columnes necessàries han estat canviades"; break;
case "Non mostrare prenotazioni che non hanno almeno una di queste colonne necessarie (non selezionarene per mostrare tutte)":	$messaggio = "Columnes necessàries per mostrar les reserves (no seleccionar-ne cap per mostrar-les totes)"; break;
case "cambia le colonne necessarie":  		$messaggio = "canviar les columnes necessàries"; break;
case "Metodo di pagamento eliminato":  		$messaggio = "Mitjpa de pagament eliminat"; break;
case "Nuovo metodo di pagamento aggiunto":  	$messaggio = "Nou mitjà de pagament afegit"; break;
case "Metodi di pagamento":  			$messaggio = "Mitjans de pagament"; break;
case "elimina":  				$messaggio = "eliminar"; break;
case "aggiungi":  				$messaggio = "afegir"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Quadre de disponibilitat"; break;
case "non mostrare":  				$messaggio = "no mostrar"; break;
case "Il modo di visualizzazione del quadro di disponibilità è stato cambiato":	$messaggio = "El mode de visualització del quadre de disponidilitat ha estat canviat"; break;
case "Controllo disponibilità":  		$messaggio = "Cerca disponibilitat"; break;
case "settimane di intervallo":  		$messaggio = "setmanes d'intèrval"; break;
case "giorni di intervallo":  			$messaggio = "dies d'intèrval"; break;
case "Giorno di inizio/fine settimana cambiato":	$messaggio = "Dia d'inici/final de setmana canviat"; break;
case "Giorno di inizio/fine settimana nelle tabelle":	$messaggio = "Dia d'inici/final de setmana a les taules"; break;
case "Anno":  					$messaggio = "Any"; break;
case "Creazione automatica del nuovo anno disattivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Creació automàtica del nou any desactivada (importando les tats de l'any anterior al primer login d'un usuari)"; break;
case "Creazione automatica del nuovo anno attivata (importando i dati dall'anno precedente al primo login di un utente)":	$messaggio = "Creació automàtica del nou any activada (importando les tats de l'any anterior al primer login d'un usuari)"; break;
case "Creazione automatica nuovo anno disattivata":	$messaggio = "Creació automàtica nou any desactivada"; break;
case "Creazione automatica nuovo anno attivata":	$messaggio = "Creació automàtica nou any activada"; break;
case "Sostituisci la parola":  			$messaggio = "Substituïr el mot"; break;
case "Parole da sostituire":  			$messaggio = "Mots a substituïr"; break;
case "La parola da sostituire è stata aggiunta":	$messaggio = "El mot a substituïr ha estat afegit"; break;
case "La parola da sostituire è stata eliminata":	$messaggio = "El mot a substituïr ha estat eliminat"; break;
case "modifica il documento":  			$messaggio = "modifica el document"; break;
case "Aggiungi ai documenti":  			$messaggio = "Afegeix als documents"; break;
case "variabili personalizzate":  		$messaggio = "variables personalitzades"; break;
case "Cambia il numero dei documenti":  	$messaggio = "Canviar la quantitat de documents"; break;
case "Il numero di documenti è stato cambiato":	$messaggio = "La quantitat de documents ha estat canviada"; break;
case "Il numero di documenti è sbagliato":  	$messaggio = "La quantitat de documents és errònia"; break;
case "Indirizzo email":  			$messaggio = "Email"; break;
case "Mascherare la provenienza delle email sull'envelope":	$messaggio = "Enmascarar la provinença dels emails"; break;
case "Il mascheramento della provenienza delle email è stato cambiato":	$messaggio = "L'enmascarament de la provinença dels emails ha estat canviat"; break;
case "SI":  					$messaggio = "SÍ"; break;
case "NO":  					$messaggio = "NO"; break;
case "Cartelle in cui creare le pagine per il sito web":	$messaggio = "Carpetes on crear les pàgines pel lloc web"; break;
case "La cartella inserita <div style=\"display: inline; color: red;\">non esiste</div>":	$messaggio = "El directori inserit <div style=\"display: inline; color: red;\">no existeix</div>"; break;
case "Le cartelle dove vengono create le pagine per il sito web sono state cambiate":	$messaggio = "Els directoris on crear pàgines pel lloc web han estat canviats"; break;
case "Selezionare in modo predefinito":  	$messaggio = "Seleccionar de manera predefinida"; break;
case "tutte le prenotazioni":  			$messaggio = "totes les reserves"; break;
case "prenotazioni del periodo corrente":  	$messaggio = "reserves del període actual"; break;
case "La selezione predefinita delle prenotazioni nella tabella con tutte le prenotazioni è stata cambiata":	$messaggio = "La selecció predefinida de les reserves a la taula de reserves ha estat canviada"; break;
case "Numero di righe dopo cui ripetere la riga delle date":	$messaggio = "Quantitat de línies abans de repetir la línia de les dates"; break;
case "Il numero  di righe dopo cui ripetere la riga delle date è stato cambiato":	$messaggio = "La quantitat de línies abans de repetir la línia de les dates ha estat canviat"; break;
case "orario entrata stimato":  		$messaggio = "hora d'arribada orientativa"; break;
case "Mostrare i giorni nella riga delle date?":	$messaggio = "Mostrar els dies a la línia de les dates?"; break;
case "I giorni da mostrare nella tabella dei mesi sono stati cambiati":	$messaggio = "Els dies a mostrar a la línia de les dates han estat canviats"; break;
case "Nazioni":  				$messaggio = "Països"; break;
case "Elimina tutte":  				$messaggio = "Eliminar totes"; break;
case "Ripristina predefinite":  		$messaggio = "Restaurar predefinides"; break;
case "Importa le nazioni":  			$messaggio = "Importar els païss"; break;
case "Regioni/provincie":  			$messaggio = "Províncies"; break;
case "Importa le regioni/provincie":  		$messaggio = "Importar les províncies"; break;
case "Nazione cancellata":  			$messaggio = "País esborrat"; break;
case "Regione/provincia cancellata":  		$messaggio = "Província esborrada"; break;
case "Nuova nazione aggiunta":  		$messaggio = "Nou país afegit"; break;
case "Nazioni predefinite ripristinate":  	$messaggio = "Països predefinides restaurats"; break;
case "Nazioni cancellate":  			$messaggio = "Països esborrats"; break;
case "Nazioni importate":  			$messaggio = "Països importats"; break;
case "Nuova regione/provincia aggiunta":  	$messaggio = "Nova província afegida"; break;
case "Regioni/provincie predefinite ripristinate":	$messaggio = "Províncies predefinides restaurades"; break;
case "Regioni/provincie cancellate":  		$messaggio = "Províncies esborrades"; break;
case "Regioni/provincie importate":  		$messaggio = "Províncies importades"; break;
case "Parentele":  				$messaggio = "Vincles familiars"; break;
case "Importa le parentele":  			$messaggio = "Importar els vincles familiars"; break;
case "Parentela cancellata":  			$messaggio = "Vincle familiar esborrat"; break;
case "Nuova parentela aggiunta":  		$messaggio = "Nou vincle familiar afegit"; break;
case "Parentele predefinite ripristinate":  	$messaggio = "Vincles familiars restaurats"; break;
case "Parentele cancellate":  			$messaggio = "Vincles familiars esborrats"; break;
case "Parentele importate":  			$messaggio = "Vincles familiars importats"; break;
case "origine":  				$messaggio = "origen"; break;
case "Origini delle prenotazioni":  		$messaggio = "Origens de les reserves"; break;
case "Nuova origine delle prenotazioni aggiunta":	$messaggio = "Nou origen de les reserves afegit"; break;
case "Origine delle prenotazioni eliminata":  	$messaggio = "Origen de les reserves eliminat"; break;
case "Nome combinazione":  			$messaggio = "Nom combinació"; break;
case "prenotazioni correnti e future":  	$messaggio = "reserves actuals i futures"; break;
case "Personalizzazioni di <b>tutti gli utenti</b>":  	$messaggio = "Personaliztacions de <b>tots els usuaris</b>"; break;
case "tutti gli utenti":  			$messaggio = "tots els usuaris"; break;
case "Personalizzazioni del gruppo":  		$messaggio = "Personaliztacions del grup"; break;
case "gruppo":  				$messaggio = "grup"; break;
case "Log delle query di modifica generate":	$messaggio = "Registre de les ordres de modificació fetes"; break;
case "da tutti gli utenti":  			$messaggio = "per tots els usuaris"; break;
case "dall'utente":  				$messaggio = "per l'usuari"; break;
case "dal gruppo":  				$messaggio = "pel grup"; break;
case "attivato":				$messaggio = "activat"; break;
case "disattivato":				$messaggio = "desactivat"; break;
case "Vedi i log":  				$messaggio = "Mirar els registres"; break;
case "Log delle query di modifica effettuate dagli utenti negli ultimi":	$messaggio = "Logs de les ordres de modificació fetes pels usuaris en els últims"; break;
case "giorni":  				$messaggio = "dies"; break;
case "Utente":  				$messaggio = "Usuari"; break;
case "Data":  					$messaggio = "Data"; break;
case "Query":  					$messaggio = "Ordre"; break;
case "Cancella tutti i log":  			$messaggio = "Esborrar tots els registres"; break;
case "Log delle query di modifica degli utenti normali disattivato":	$messaggio = "Registre de les ordres de modificació dels usuaris normals desactivat"; break;
case "Log delle query di modifica degli utenti normali attivato":	$messaggio = "Registre de les ordres de modificació dels usuaris normals activat"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Aliniar la disponibilitat amb la data d'arribada?"; break;
case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "L'aliniació dels dies amb la disponibilitat a planning per mesos ha estat canviada"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Aliniar la disponibilitat amb les dates d'arribada podria generar confusió i errors amb les dates de sortida, segur que cal continuar?"; break;
case "Documenti di identità":  			$messaggio = "Documents d'identitat"; break;
case "Tipo di documento di identità eliminato":	$messaggio = "Tipus de document d'identitat eliminat"; break;
case "Nuovo tipo di documento di identità aggiunto":	$messaggio = "Nou tipus de document d'identitat afegit"; break;
case "Tipi di documento di identità predefiniti ripristinati":	$messaggio = "Tipus de document d'identitat predefinits restaurats"; break;
case "Tipi di documento di identità cancellati":	$messaggio = "Tipus de document d'identitat esborrats"; break;
case "Tipi di documento di identità importati":	$messaggio = "Tipus de document d'identitat importats"; break;
case "Importa i documenti di identità":  	$messaggio = "Importar els documents d'identitat"; break;
case "codice":  				$messaggio = "codi"; break;
case "Nuova nazione":  				$messaggio = "Nou país"; break;
case "Nuova regione/provincia":  		$messaggio = "Nova província"; break;
case "Nuovo documento d'identità":  		$messaggio = "Nou document d'identitat"; break;
case "Nuova parentela":  			$messaggio = "Nou vincle familiar"; break;
case "Elimina tutti":  				$messaggio = "Eliminar tots"; break;
case "Ripristina predefiniti":  		$messaggio = "Restaurar predefinits"; break;
case "Città":  					$messaggio = "Ciudades"; break;
case "Nuova città":  				$messaggio = "Nova ciutat"; break;
case "Importa le città":  			$messaggio = "Importar les ciutats"; break;
case "Città cancellata":  			$messaggio = "Ciutat esborrada"; break;
case "Nuova città aggiunta":  			$messaggio = "Nova ciutat afegida"; break;
case "Città predefinite ripristinate":  	$messaggio = "Ciutats predefinides restaurades"; break;
case "Città cancellate":  			$messaggio = "Ciutats esborrades"; break;
case "Città importate":  			$messaggio = "Ciutats importades"; break;
case "nella regione/provincia di":  		$messaggio = "a la província de"; break;
case "nella nazione":  				$messaggio = "al país"; break;
case "Titoli dei clienti":  			$messaggio = "Títols dels client"; break;
case "sesso":  					$messaggio = "gènere"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Titolo dei clienti eliminato":  		$messaggio = "Títol dels clients eliminat"; break;
case "Nuovo titolo dei clienti aggiunto":  	$messaggio = "Nou títol dels clients afegit"; break;
case "I dati della struttura sono stati cambiati":	$messaggio = "Les dades de l'explotació han estat canviades"; break;
case "Dati della struttura":  			$messaggio = "Dades de l'explotació"; break;
case "Nome":  					$messaggio = "Nom"; break;
case "Tipo":  					$messaggio = "Tipus"; break;
case "Numero stelle":  				$messaggio = "Categoria estrelles"; break;
case "Nazione":  				$messaggio = "País"; break;
case "Comune":  				$messaggio = "Ciutat"; break;
case "Indirizzo":  				$messaggio = "Adreça"; break;
case "CAP":  					$messaggio = "Codi postal"; break;
case "Telefono":  				$messaggio = "Telèfon"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Codice fiscale":  			$messaggio = "Codi fiscal"; break;
case "Modifica i dati della struttura":  	$messaggio = "Modificar les dades de l'explotació"; break;
case "Clicca su un documento per modificarlo":	$messaggio = "Clicar sobre un document per modificar-lo"; break;
case "Cambia l'ordine dei documenti":  		$messaggio = "Canviar l'ordre dels documents"; break;
case "Applica i cambiamenti":  			$messaggio = "Aplicar els canvis"; break;
case "ex":  					$messaggio = "ex"; break;
case "L'ordine dei documenti è stato cambiato":	$messaggio = "L'ordre dels documents ha estat canviat"; break;
case "Sito web":  				$messaggio = "Lloc web"; break;
case "Nome contatto":  				$messaggio = "Persona de contacte"; break;
case "l'ordine delle tariffe è stato cambiato":	$messaggio = "l'ordre de les tarifes ha estat canviat"; break;
case "cambia l'ordine delle tariffe":  		$messaggio = "canviar l'ordre de les tarifes"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "valore predefinito a cui arrotondare le percentuali dei prezzi":	$messaggio = "valor predefinit al qual arrodonir els percentages dels preus"; break;
case "il":  					$messaggio = "el"; break;
case "è stato cambiato":  			$messaggio = "ha estat canviat"; break;
case "password per la visualizzazione dei dati delle carte di credito":	$messaggio = "contrasenya per veure les dades de les targetes de crèdit"; break;
case "attivata":  				$messaggio = "activada"; break;
case "disattivata":  				$messaggio = "desactivada"; break;
case "cambia la password":  			$messaggio = "canviar contrasenya"; break;
case "<b>Attenzione</b>: se si perde questa password non sarà più possibile leggere i dati delle carte di credito inserite":	$messaggio = "<b>Atenció</b>: si es perdés aquesta contrasenya ja no seria possible llegir les dades de les targetes de crèdit"; break;
case "nuova password":  			$messaggio = "nova contrasenya"; break;
case "ripetere password":  			$messaggio = "repetir contrasenya"; break;
case "attiva la password":  			$messaggio = "activar la contrasenya"; break;
case "le password inserite non coincidono":  	$messaggio = "les contrasenyes inseirdes no coincideixen"; break;
case "errore nelle funzioni ssl":  		$messaggio = "error a les funcions SSL"; break;
case "<b class=\"colred\">Attenzione</b>: tutti i dati delle carte di credito verranno cancellati":	$messaggio = "<b class=\"colred\">Atenció</b>: totes les dades de les targetes de crèdit seran esborrades"; break;
case "continua":  				$messaggio = "continua"; break;
case "vecchia password":  			$messaggio = "contrasenya vella"; break;
case "cambiata":  				$messaggio = "canviada"; break;
case "piano":  					$messaggio = "pis"; break;
case "casa":  					$messaggio = "casa"; break;
case "2°":  					$messaggio = "2°"; break;
case "3°":  					$messaggio = "3°"; break;
case "2° codice":  				$messaggio = "2on codi"; break;
case "3° codice":  				$messaggio = "3er codi"; break;
case "Tabella con i documenti salvati":  	$messaggio = "Taula amb els documents desats"; break;
case "Il numero delle righe della tabella con i documenti salvati è stato cambiato":	$messaggio = "La quantitat de línies de la taula amb els documents desats ha estat canviada"; break;
case "valore a cui arrotondare le percentuali delle tasse":	$messaggio = "valor al qual arrodonir els pertentatges dels imports"; break;
case "commissioni":  				$messaggio = "comissions"; break;
case "resto commissioni":  			$messaggio = "resta comissions"; break;
case "documenti salvati":  			$messaggio = "documents desats"; break;
case "Scegli le righe aggiuntive da mostrare":	$messaggio = "Escollir les línies extres a mostrar"; break;
case "tasse":  					$messaggio = "impostos"; break;
case "trasferito in cassa":  			$messaggio = "transferit a caixa"; break;
case "cambia le righe":  			$messaggio = "canviar les línies"; break;
case "Le righe aggiuntive sono state cambiate":	$messaggio = "Les línies extres han estat canviades"; break;
case "soldi prenotazioni cancellate":  		$messaggio = "quantitats de reserves esborrades"; break;
case "cognome ospite se differente":  		$messaggio = "cognom hoste si fos diferent"; break;
case "Ragione sociale":  			$messaggio = "Raó social"; break;
case "URL del logo":  				$messaggio = "URL del logo"; break;
case "Nome delle unità da affittare":  		$messaggio = "Nom de les unitats a llogar"; break;
case "nome personalizzato":  			$messaggio = "nom personalizat"; break;
case "genere":  				$messaggio = "gènere"; break;
case "m":  					$messaggio = "m"; break;
case "f":  					$messaggio = "f"; break;
case "Il nome delle unità da affittare è stato cambiato":	$messaggio = "El nom de les unitats a llogar ha estat canviat"; break;
case "Tabelle con le casse":  			$messaggio = "Taules de caixes"; break;
case "Il numero delle righe delle tabelle con le casse è stato cambiato":	$messaggio = "La quantitat de línies de les taules de caixes ha estat canviat"; break;
case "Documenti":  				$messaggio = "Documents"; break;
case "documento":  				$messaggio = "document"; break;
case "percorsi separati da virgole relativi":	$messaggio = "comma separated paths relative"; break;
case "alla cartella di HotelDruid, se non iniziano con /":	$messaggio = "to the HotelDruid directory, if they don't begin with /"; break;
case "Non ho i permessi di scrittura sulla cartella":	$messaggio = "I don't have write permissions on directory"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Documento":  				$messaggio = "Document"; break;
case "totale":  				$messaggio = "total"; break;
case "singolare":  				$messaggio = "singular"; break;
case "plurale":  				$messaggio = "plural"; break;
case "Elimina il documento":  			$messaggio = "Delete document"; break;
case "Sei sicuro di voler eliminare il documento":	$messaggio = "Are you sure you want to delete document"; break;
case "Il documento è stato eliminato":	$messaggio = "The document has been deleted"; break;
case "Campi da considerare per la ricerca dei clienti":	$messaggio = "Fields to be considered when searching clients"; break;
case "cognome":  				$messaggio = "surname"; break;
case "email":  					$messaggio = "email"; break;
case "nome":  					$messaggio = "name"; break;
case "telefono":  				$messaggio = "telephone"; break;
case "città":  					$messaggio = "city"; break;
case "indirizzo":  				$messaggio = "address"; break;
case "codice postale":  			$messaggio = "postal code"; break;
case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "The fields to be considered when searching clients have been changed"; break;
case "Nome delle unità singole":  		$messaggio = "Name of single units"; break;
case "Tabella dei messaggi":  			$messaggio = "Messages table"; break;
case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "The number of rows of the messages table has been changed"; break;
case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Download emails for availability enquiries from mail server"; break;
case "per es.":  				$messaggio = "e.g."; break;
case "Protocollo":  				$messaggio = "Protocol"; break;
case "Porta":  					$messaggio = "Port"; break;
case "default":  				$messaggio = "default"; break;
case "persoalizzata":  				$messaggio = "custom"; break;
case "Nome utente":  				$messaggio = "Username"; break;
case "Password":  				$messaggio = "Password"; break;
case "lasciare vuota per chiedere ogni volta":	$messaggio = "leave empty to ask each time"; break;
case "Identificazione messaggi di richiesta":	$messaggio = "Enquiry messages identification"; break;
case "Messaggio iniziale":  			$messaggio = "First post"; break;
case "Qualsiasi messaggio":  			$messaggio = "Any post"; break;
case "da":  					$messaggio = "from"; break;
case "con oggetto contenete":  			$messaggio = "with subject containing"; break;
case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "The data to download emails are wrong or incomplete"; break;
case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "The download of emails for availability enquiries from mail server has been changed"; break;
case "Colori delle prenotazioni":  		$messaggio = "Reservations colors"; break;
case "Tutto pagato":  				$messaggio = "All paid"; break;
case "Caparra pagata":  			$messaggio = "Deposit paid"; break;
case "Confermate":  				$messaggio = "Confirmed"; break;
case "Non confermate":  			$messaggio = "Not confirmed"; break;
case "I colori sono sbagliati":  		$messaggio = "Colors are wrong"; break;
case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Reservations colors have been changed"; break;
case "Campi personalizzati dei clienti":  	$messaggio = "Custom fields for clients"; break;
case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "New custom field for clients added"; break;
case "Campo personalizzato dei clienti eliminato":	$messaggio = "Custom field for clients deleted"; break;
case "tipo":  					$messaggio = "type"; break;
case "booleano":  				$messaggio = "boolean"; break;
case "testo":  					$messaggio = "text"; break;
case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "The custom field contains not allowed characters"; break;
case "Gestire anche i codici CVC delle carte di credito":	$messaggio = "Manage the CVC codes from credit cards too"; break;
case "Esonero di responsabilità":  		$messaggio = "Disclaimer"; break;
case "la gestione dei codici CVC avverrà sotto la propria responsabilità, essendo a conoscenza che gli standard di sicurezza PCI ne vietano la registrazione":	$messaggio = "the CVC codes will be managed under your own responsibility, being aware that PCI security standards forbid their storage"; break;
case "L'accettazione di questa clausola conferma che gli sviluppatori di questo software sono liberi da ogni responsibilità sulla sicurezza di questi dati":	$messaggio = "Accepting this clause confirms that the developers of this software are free from all responsibilities regarding the security of these data"; break;
case "Accetto":  				$messaggio = "I Accept"; break;
case "Declino":  				$messaggio = "I Decline"; break;
case "La gestione dei codici cvc è stata cambiata":	$messaggio = "The management of CVC codes has been changed"; break;
case "Scegli le righe con i totali da mostrare":	$messaggio = "Choose which totals to show in rows"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case "mensile":  				$messaggio = "montly"; break;
case "tabella":  				$messaggio = "table"; break;
case "Le righe da mostrare nelle tabelle delle casse sono state cambiate":	$messaggio = "Rows shown in cashobxes tables have been changed"; break;
case "partenze e prenotazioni correnti":  	$messaggio = "departures and current reservations"; break;
case "Commenti personalizzati delle prenotazioni":	$messaggio = "Custom comments for reservations"; break;
case "Commento personalizzato della prenotazione eliminato":	$messaggio = "Custom comment for reservation deleted"; break;
case "Nuovo commento personalizzato della prenotazione aggiunto":	$messaggio = "New custom comment for reservation added"; break;
case "Punto vendita ed inventario":  		$messaggio = "Point of sale and inventory"; break;
case "Ordinamento nell'inventario e punto vendita":	$messaggio = "Sorting in inventory and point of sale"; break;
case "alfabetico":  				$messaggio = "alphabetically"; break;
case "per ordine di inserimento":  		$messaggio = "by insertion order"; break;
case "Tasti per operazioni nel punto vendita":	$messaggio = "Buttons for operations in point of sale"; break;
case "L'ordinamento nell'inventario e nel punto vendita è stato cambiato":	$messaggio = "Sorting in inventory and point of sale has been changed"; break;
case "I tasti per operazioni nel punto vendita sono stati cambiati":	$messaggio = "Buttons for operations in point of sale have been changed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>